/*******************************************************************************
 *   Filename:       bsp.c
 *   Revised:        All copyrights reserved to Roger-WY.
 *   Revision:       v1.0
 *   Writer:	     Roger-WY.
 *
 *   Description:    板级支持包
 *
 *   Notes:
 *     				E-mail:261313062@qq.com
 *
 *******************************************************************************/

#include "bsp.h"

/* 定时器0初始化 125us定时 */
void bsp_timer0_config(void)
{
//    TM0PS = 0x00;           //设置定时器时钟预分频
//	AUXR |= 0x80;			//定时器时钟1T模式
//	TMOD &= 0xF0;			//设置定时器模式
//	TL0 = 0x33;				//设置定时初始值 //125微秒@22.1184MHz
//	TH0 = 0xF5;				//设置定时初始值
//	TF0 = 0;				//清除TF0标志
//	TR0 = 1;				//定时器0开始计时
//	ET0 = 1;				//使能定时器0中断

    TIM_InitTypeDef		TIM_InitStructure;						//结构定义
    TIM_InitStructure.TIM_Mode      = TIM_16BitAutoReload;	//指定工作模式,   TIM_16BitAutoReload,TIM_16Bit,TIM_8BitAutoReload,TIM_16BitAutoReloadNoMask
    TIM_InitStructure.TIM_ClkSource = TIM_CLOCK_1T;		//指定时钟源,     TIM_CLOCK_1T,TIM_CLOCK_12T,TIM_CLOCK_Ext
    TIM_InitStructure.TIM_ClkOut    = DISABLE;				//是否输出高速脉冲, ENABLE或DISABLE
    TIM_InitStructure.TIM_Value     = (u16)(65536UL - (MAIN_Fosc / 8000UL));		//中断频率, 8000次/秒
    TIM_InitStructure.TIM_Run       = ENABLE;					//是否初始化后启动定时器, ENABLE或DISABLE
    Timer_Inilize(Timer0, &TIM_InitStructure);					//初始化Timer0	  Timer0,Timer1,Timer2,Timer3,Timer4

    NVIC_Timer0_Init(ENABLE, Priority_0);		//中断使能, ENABLE/DISABLE; 优先级(低到高) Priority_0,Priority_1,Priority_2,Priority_3
}

/*******************************************************************************
 * 名    称： bsp_Init
 * 功    能： 初始化所有的硬件设备。该函数配置CPU寄存器和外设的寄存器并初始化一些全局变量。只需要调用一次
 * 入口参数： 无
 * 出口参数： 无
 * 作　　者： Roger-WY.
 * 创建日期： 2015-06-25
 * 修    改：
 * 修改日期：
 * 备    注：
 *******************************************************************************/
void bsp_Init(void)
{
    bsp_SoftTimerInit(); //必须在硬件定时器之前调用
    bsp_timer0_config();

    bsp_LedInit();  //led初始化

    bsp_Uart1Init(); //日志打印串口

    /* 红外遥控器初始化 */
    //bsp_ir_init();

    /* 按键检测 */
    //bsp_KeyInit();

#if ( MODBUS_CFG_SLAVE_EN == 1 )
    MODS_PeripheralInit();
#endif

#ifdef CHIP_READ_PROTECT
    /***********************************************
    * 描述：Flash写保护和读保护，增加保护后，
    *       需使用JFLASH擦出芯片才可以进行下次下载与仿真。
    */

#endif

#if defined(USER_IWDG_ENABEL)
    bsp_IwdgInit(BSP_WDT_MODE_INT);
#endif

    /* 打开总中断 */
    EA = 1;

}


/*******************************************************************************
 * 名    称： bsp_RunPer1ms
 * 功    能： 该函数每隔1ms被Systick中断调用1次。详见 bsp_timer.c的定时中断服务程序。
              一些需要周期性处理的 事务可以放在此函数。比如：触摸坐标扫描。
 * 入口参数： 无
 * 出口参数： 无
 * 作　　者： Roger-WY.
 * 创建日期： 2015-06-25
 * 修    改：
 * 修改日期：
 * 备    注：
 *******************************************************************************/
void bsp_RunPer1ms(void)
{

}

/*******************************************************************************
 * 名    称： bsp_RunPer10ms
 * 功    能： 该函数每隔10ms被Systick中断调用1次。详见 bsp_timer.c的定时中断服务程序。一些需要周期性处理
 *			  的事务可以放在此函数。比如：按键扫描、蜂鸣器鸣叫控制等。
 * 入口参数： 无
 * 出口参数： 无
 * 作　　者： Roger-WY.
 * 创建日期： 2015-06-25
 * 修    改：
 * 修改日期：
 * 备    注：
 *******************************************************************************/
void bsp_RunPer10ms(void)
{
    /*
    下面的代码实现所有按键的检测。按键检测每隔10ms一次就行了，一般做40ms的滤波处理就可以
    有效过滤掉机械动作造成的按键抖动。
    */
    //bsp_KeyScan();		/* 按键扫描 */
}

/*******************************************************************************
 * 名    称： bsp_Idle
 * 功    能： 空闲时执行的函数。
 * 入口参数： 无
 * 出口参数： 无
 * 作　　者： Roger-WY.
 * 创建日期： 2015-06-25
 * 修    改：
 * 修改日期：
 * 备    注： 本函数缺省为空操作。用户可以添加喂狗、设置CPU进入休眠模式的功能。
 *******************************************************************************/
void bsp_Idle(void)
{
#if defined(USER_IWDG_ENABEL)
    /* --- 喂狗 */
    bsp_IwdgFeed();
#endif
    /* --- 让CPU进入休眠，由Systick定时中断唤醒或者其他中断唤醒 */

    /* 对于 emWin 图形库，可以插入图形库需要的轮询函数 */
    //GUI_Exec();

    /* 对于 uIP 协议实现，可以插入uip轮询函数 */

#if ( MODBUS_CFG_SLAVE_EN == 1 )
    MODS_Poll();    /* Modbus从站消息处理函数 */
#endif
#if ( MODBUS_CFG_HOST_EN == 1 )
    MODH_Poll();    /* Modbus主站消息处理函数 */
#endif

}

/*****************************  (END OF FILE) *********************************/
