#include "bsp_ir.h"

static volatile unsigned char xdata ir_ok = 0;        // 红外接收完成标志
static volatile unsigned char xdata ir_data[4] = {0}; // 红外数据存储

#define IR_IO   P35
#define IR_PORT GPIO_P3
#define IR_PIN  GPIO_Pin_5


void bsp_ir_init(void)
{

    GPIO_InitTypeDef GPIO_InitStructure; //结构定义

    GPIO_InitStructure.Pin = IR_PIN;            //指定要初始化的IO,
    GPIO_InitStructure.Mode = GPIO_OUT_OD;              //指定IO的输入或输出方式,GPIO_PullUp,GPIO_HighZ,GPIO_OUT_OD,GPIO_OUT_PP
    GPIO_Inilize(IR_PORT, &GPIO_InitStructure); //初始化

}

/* 红外(NEC)解码  */
void bsp_ir_decode(void)
{
    static unsigned char state = 0;
    static unsigned char cnt = 0;
    static unsigned char rec_data;
    static unsigned char rec_cnt = 0;
    static unsigned char i = 0;

    if (ir_ok)
        return;

    switch (state)
    {
    case 0: // 判断起始码  9m低电平
        ++cnt;
        if (IR_IO == 1) // 高电平到来
        {
            if (cnt >= 65 && cnt <= 78) // 高电平之前，维持约为9ms的低电平，cnt=72=9ms，
            {
                state = 1; // 进入下一状态
                cnt = 1;
            }
            else
            {
                cnt = 0;
            }
        }
        break;

    case 1: // 判断引导码  4.5ms高电平
        ++cnt;
        if (IR_IO == 0) // 低电平到来
        {
            if (cnt >= 30) // 低电平来之前，维持了约为4.5ms的高电平 cnt=36=4.5ms
            {
                state = 2;
                cnt = 1;
                rec_cnt = 0;
                i = 0;
            }
            //					else if(cnt >= 16)	//低电平来之前，维持了约为2.25ms的高电平 cnt=18=2.25ms
            //					{
            //						ir_data[0] = 0;
            //						ir_data[1] = 0;
            //						ir_data[2] = 0;
            //						ir_data[3] = 0;
            //						ir_ok = 1;    //標志接收完成
            //						rec_cnt = 0;
            //						state = 0;
            //						cnt = 0;
            //					}
            else // 不合法退回最初状态
            {
                state = 0;
                cnt = 0;
            }
        }
        else // 为高电平
        {
            if (cnt > 50) // 长时间为高电平 退回最初状态
            {
                cnt = 0;
                state = 0;
            }
        }
        break;

        // case 2 和 case 3 为接收数据
    case 2: // 560us的低电平
        ++cnt;
        if (IR_IO == 1) // 高电平到来
        {
            if (cnt >= 3) // 高电平到来之前 维持了约560us的低电平 cnt=4.48=560us
            {
                state = 3;
                cnt = 1;
            }
        }
        else // 为低电平
        {
            if (cnt > 8) // 长时间处于低电平 错误 返回
            {
                state = 0;
                cnt = 0;
            }
        }
        break;
    case 3: // 560 或 1.69ms  高电平
        ++cnt;
        if (IR_IO == 0) // 低电平到来
        {
            rec_data >>= 1;
            if (cnt > 10) // 低电平到来時 高电平维持>560us bit值为1        cnt=4.48=560us
            {
                rec_data |= 0x80;
            }

            if (++i >= 8) // 是否接收完一个字节
            {
                i = 0;
                ir_data[rec_cnt] = rec_data; // 保存
                if (++rec_cnt >= 4)          // 接收完所有数据
                {
                    ir_ok = 1; // 接收完成标志位
                    rec_cnt = 0;
                    state = 0;
                    cnt = 0;
                }
                else // 还没有接收完 返回上一步继续
                {
                    state = 2;
                    cnt = 1;
                }
            }
            else // 还没有接收完 返回上一步继续
            {
                state = 2;
                cnt = 1;
            }
        }
        else // 为高电平
        {
            if (cnt > 15) // 长时间为高电平   错误 返回
            {
                state = 0;
                cnt = 0;
            }
        }
        break;
    }
}


uint8_t bsp_ir_get_value(uint8_t *pIrKey)
{
    if(ir_ok == 0)//无红外时返回
		return 0;

	if((ir_data[0]==0x04)&&(ir_data[1]==0xac)&&((ir_data[2]+ir_data[3])==0xff))
	{
        *pIrKey = ir_data[2];
        return 1;
    }

    return 0;
}

void bsp_clear_ir_flag(void)
{
    ir_ok = 0;
}
